@@ -1,13 +1,16 @@
 package Net::Packet::Layer2;
 
-# $Date: 2005/01/18 22:09:23 $
-# $Revision: 1.1.1.1.4.9 $
+# $Date: 2005/02/01 16:29:16 $
+# $Revision: 1.1.1.1.4.10 $
 
 require Net::Packet::Layer;
 our @ISA = qw(Net::Packet::Layer);
 
 use Net::Packet::Consts qw(:layer);
 
+require Net::Packet;
+our $VERSION = $Net::Packet::VERSION;
+
 sub layer { NP_LAYER_N_2 }
 
 sub _is    { (shift->is eq shift()) ? 1 : 0 }
