@@ -1,7 +1,7 @@
 package Net::Packet::NULL;
 
-# $Date: 2005/01/26 21:57:49 $
-# $Revision: 1.1.2.15 $
+# $Date: 2005/02/01 16:29:16 $
+# $Revision: 1.1.2.16 $
 
 use strict;
 use warnings;
@@ -12,6 +12,9 @@ our @ISA = qw(Net::Packet::Layer2 Class::Gomor::Hash);
 
 use Net::Packet::Consts qw(:null :layer);
 
+require Net::Packet;
+our $VERSION = $Net::Packet::VERSION;
+
 our @AS = qw(
    type
 );
